# -*- encoding: utf-8 -*-

from astropy.coordinates import BarycentricMeanEcliptic

"""The coordinate system used by the framework"""
DEFAULT_COORDINATE_SYSTEM = BarycentricMeanEcliptic()

"""The time scale used by the framework"""
DEFAULT_TIME_SCALE = "tdb"
